#line 2 "lexssh.c"
 /* -*- c -*- */
 /*
  * Lexer for a2ps.
  *
  * Copyright (c) 1988, 89, 90, 91, 92, 93 Miguel Santana
  * Copyright (c) 1995, 96, 97, 98 Akim Demaille, Miguel Santana
  *
  */
 
 /*
  * This file is part of a2ps.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 3, or (at your option)
  * any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; see the file COPYING.  If not, see
  * <https://www.gnu.org/licenses/gpl-3.0.html>.

  */
 
 /*
  * $Id: lexssh.l,v 1.1.1.1.2.1 2007/12/29 01:58:35 mhatta Exp $
  */
 
 #include <config.h>
 
 #include "main.h"
 #include "yy2ssh.h"
 #include "parsessh.h"
 #include "xobstack.h"

#line 42 "lexssh.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer ssh_create_buffer
#define yy_delete_buffer ssh_delete_buffer
#define yy_scan_buffer ssh_scan_buffer
#define yy_scan_string ssh_scan_string
#define yy_scan_bytes ssh_scan_bytes
#define yy_init_buffer ssh_init_buffer
#define yy_flush_buffer ssh_flush_buffer
#define yy_load_buffer_state ssh_load_buffer_state
#define yy_switch_to_buffer ssh_switch_to_buffer
#define yypush_buffer_state sshpush_buffer_state
#define yypop_buffer_state sshpop_buffer_state
#define yyensure_buffer_stack sshensure_buffer_stack
#define yy_flex_debug ssh_flex_debug
#define yyin sshin
#define yyleng sshleng
#define yylex sshlex
#define yylineno sshlineno
#define yyout sshout
#define yyrestart sshrestart
#define yytext sshtext
#define yywrap sshwrap
#define yyalloc sshalloc
#define yyrealloc sshrealloc
#define yyfree sshfree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yy_create_buffer
#define ssh_create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer ssh_create_buffer
#endif

#ifdef yy_delete_buffer
#define ssh_delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer ssh_delete_buffer
#endif

#ifdef yy_scan_buffer
#define ssh_scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer ssh_scan_buffer
#endif

#ifdef yy_scan_string
#define ssh_scan_string_ALREADY_DEFINED
#else
#define yy_scan_string ssh_scan_string
#endif

#ifdef yy_scan_bytes
#define ssh_scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes ssh_scan_bytes
#endif

#ifdef yy_init_buffer
#define ssh_init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer ssh_init_buffer
#endif

#ifdef yy_flush_buffer
#define ssh_flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer ssh_flush_buffer
#endif

#ifdef yy_load_buffer_state
#define ssh_load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state ssh_load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define ssh_switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer ssh_switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define sshpush_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state sshpush_buffer_state
#endif

#ifdef yypop_buffer_state
#define sshpop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state sshpop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define sshensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack sshensure_buffer_stack
#endif

#ifdef yylex
#define sshlex_ALREADY_DEFINED
#else
#define yylex sshlex
#endif

#ifdef yyrestart
#define sshrestart_ALREADY_DEFINED
#else
#define yyrestart sshrestart
#endif

#ifdef yylex_init
#define sshlex_init_ALREADY_DEFINED
#else
#define yylex_init sshlex_init
#endif

#ifdef yylex_init_extra
#define sshlex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra sshlex_init_extra
#endif

#ifdef yylex_destroy
#define sshlex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy sshlex_destroy
#endif

#ifdef yyget_debug
#define sshget_debug_ALREADY_DEFINED
#else
#define yyget_debug sshget_debug
#endif

#ifdef yyset_debug
#define sshset_debug_ALREADY_DEFINED
#else
#define yyset_debug sshset_debug
#endif

#ifdef yyget_extra
#define sshget_extra_ALREADY_DEFINED
#else
#define yyget_extra sshget_extra
#endif

#ifdef yyset_extra
#define sshset_extra_ALREADY_DEFINED
#else
#define yyset_extra sshset_extra
#endif

#ifdef yyget_in
#define sshget_in_ALREADY_DEFINED
#else
#define yyget_in sshget_in
#endif

#ifdef yyset_in
#define sshset_in_ALREADY_DEFINED
#else
#define yyset_in sshset_in
#endif

#ifdef yyget_out
#define sshget_out_ALREADY_DEFINED
#else
#define yyget_out sshget_out
#endif

#ifdef yyset_out
#define sshset_out_ALREADY_DEFINED
#else
#define yyset_out sshset_out
#endif

#ifdef yyget_leng
#define sshget_leng_ALREADY_DEFINED
#else
#define yyget_leng sshget_leng
#endif

#ifdef yyget_text
#define sshget_text_ALREADY_DEFINED
#else
#define yyget_text sshget_text
#endif

#ifdef yyget_lineno
#define sshget_lineno_ALREADY_DEFINED
#else
#define yyget_lineno sshget_lineno
#endif

#ifdef yyset_lineno
#define sshset_lineno_ALREADY_DEFINED
#else
#define yyset_lineno sshset_lineno
#endif

#ifdef yywrap
#define sshwrap_ALREADY_DEFINED
#else
#define yywrap sshwrap
#endif

#ifdef yyalloc
#define sshalloc_ALREADY_DEFINED
#else
#define yyalloc sshalloc
#endif

#ifdef yyrealloc
#define sshrealloc_ALREADY_DEFINED
#else
#define yyrealloc sshrealloc
#endif

#ifdef yyfree
#define sshfree_ALREADY_DEFINED
#else
#define yyfree sshfree
#endif

#ifdef yytext
#define sshtext_ALREADY_DEFINED
#else
#define yytext sshtext
#endif

#ifdef yyleng
#define sshleng_ALREADY_DEFINED
#else
#define yyleng sshleng
#endif

#ifdef yyin
#define sshin_ALREADY_DEFINED
#else
#define yyin sshin
#endif

#ifdef yyout
#define sshout_ALREADY_DEFINED
#else
#define yyout sshout
#endif

#ifdef yy_flex_debug
#define ssh_flex_debug_ALREADY_DEFINED
#else
#define yy_flex_debug ssh_flex_debug
#endif

#ifdef yylineno
#define sshlineno_ALREADY_DEFINED
#else
#define yylineno sshlineno
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    /* Note: We specifically omit the test for yy_rule_can_match_eol because it requires
     *       access to the local variable yy_act. Since yyless() is a macro, it would break
     *       existing scanners that call yyless() from OUTSIDE yylex.
     *       One obvious solution it to make yy_act a global. I tried that, and saw
     *       a 5% performance hit in a non-yylineno scanner, because yy_act is
     *       normally declared as a register variable-- so it is not worth it.
     */
    #define  YY_LESS_LINENO(n) \
            do { \
                int yyl;\
                for ( yyl = n; yyl < yyleng; ++yyl )\
                    if ( yytext[yyl] == '\n' )\
                        --yylineno;\
            }while(0)
    #define YY_LINENO_REWIND_TO(dst) \
            do {\
                const char *p;\
                for ( p = yy_cp-1; p >= (dst); --p)\
                    if ( *p == '\n' )\
                        --yylineno;\
            }while(0)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart ( FILE *input_file  );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size  );
void yy_delete_buffer ( YY_BUFFER_STATE b  );
void yy_flush_buffer ( YY_BUFFER_STATE b  );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state ( void );

static void yyensure_buffer_stack ( void );
static void yy_load_buffer_state ( void );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file  );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size  );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len  );

void *yyalloc ( yy_size_t  );
void *yyrealloc ( void *, yy_size_t  );
void yyfree ( void *  );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */
typedef flex_uint8_t YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;

extern int yylineno;
int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state ( void );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  );
static int yy_get_next_buffer ( void );
static void yynoreturn yy_fatal_error ( const char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;
#define YY_NUM_RULES 217
#define YY_END_OF_BUFFER 218
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[901] =
    {   0,
        2,    2,    0,    0,    0,    0,  218,  185,    2,    2,
        3,    1,  186,  185,    4,  185,  185,  185,  185,  185,
      185,  185,  185,  185,  185,  185,  185,  185,  185,  185,
      185,  185,  185,  185,  185,  185,  185,  201,  200,  187,
      217,  216,  215,  202,  217,  185,    2,    1,  185,  185,
      185,  185,  185,  185,  185,  185,  185,  185,  185,  185,
      137,  185,  185,  185,  185,  185,  185,  185,  185,  185,
      185,  185,  185,  185,  185,  185,  185,  185,  185,  185,
      185,  185,  185,  185,  185,  185,  185,  185,  185,  185,
      185,  185,  185,  185,  185,  185,  185,  185,  185,  185,

      185,  185,  185,  185,  185,  185,  185,  143,  185,  185,
      185,  185,  185,  185,  152,  154,  185,  185,  185,  185,
      185,  185,  185,  201,  199,  188,  190,  191,  192,  193,
      194,  195,  196,  197,  198,  199,  216,  214,  203,  205,
      206,  207,  208,  209,  210,  211,  212,  213,  214,   91,
      185,  185,  185,  185,  185,  185,  185,  185,  185,  185,
      185,  185,  185,  185,  185,  185,  185,  185,  185,  185,
      185,   94,  185,  185,  185,  185,   21,   22,  185,  185,
       24,  185,   95,  185,  185,  185,  185,  185,  185,   32,
      185,  185,  185,  185,  185,  185,  185,  185,  185,  185,

      185,  185,  185,  185,  185,  185,  185,  185,  185,  185,
      185,  185,  185,  185,  185,  185,  107,  185,  185,  185,
      185,  185,  185,  185,   50,  185,  185,  185,   51,  185,
      185,  185,  185,  185,  185,   53,   80,  185,  185,  185,
      185,  185,  185,  185,  185,  185,  185,  185,  185,  185,
      185,  185,  185,  185,  185,  185,   96,   61,  185,  185,
      185,  185,  142,  185,  185,  185,  149,  185,  185,  185,
      185,  185,  185,  185,  185,  185,  185,  185,  185,  185,
      188,  189,  203,  204,  185,  185,  185,  185,  185,  185,
      185,  185,  185,  185,  185,  185,  175,  176,  177,  178,

      185,  185,   11,  185,  185,  185,   16,  185,  185,  185,
      185,  185,  185,  185,   14,   33,   26,  185,  185,   28,
      185,  185,  185,  185,  185,  185,  185,  185,  185,  185,
      100,  185,  185,   40,  185,  185,  185,  185,  101,  185,
      185,   86,  185,  185,  185,  185,   45,  185,  185,  185,
      185,   81,  185,  185,  134,  185,  185,  185,  185,  185,
      185,  185,   67,  185,  185,   87,  117,  185,  185,  185,
      185,  185,  185,   43,  185,  185,   62,  185,  185,  185,
      185,  185,   55,  185,  185,   64,  185,  185,  185,  130,
      185,  185,   57,  185,  185,  185,  185,  185,  185,  119,

      185,  185,  138,  185,  185,  144,  185,  185,  185,  185,
      185,  185,  185,  185,  185,  185,  185,  185,  185,  185,
      185,  188,  189,  203,  204,  185,  185,  185,  185,  168,
      185,  185,  185,  169,  165,  185,  185,  185,   10,  185,
      185,  185,  185,   17,  185,  185,  185,  185,  185,  185,
      185,  185,  185,  185,   34,  185,  185,  185,  185,   39,
      185,  185,  116,   79,  185,    8,  185,  185,  185,  185,
      185,  185,  185,  185,  185,  185,  185,  185,  185,   46,
      185,  185,  185,  185,  185,  185,  185,  185,  185,  185,
      185,  185,  185,  185,   36,  185,  114,  185,  185,  185,

      185,  185,  185,  185,  185,  185,  185,  185,  185,  115,
      185,  185,  185,  185,  185,  185,  185,  185,  185,  185,
      185,  185,  185,  185,   63,  185,  185,  185,  185,  185,
      151,  185,  185,  185,  185,  185,  185,  185,  185,  162,
      185,  185,  146,  185,  185,  185,  179,  180,  181,  182,
      185,  185,  185,  171,  172,    9,   12,  185,  185,   15,
       19,  185,  185,  185,   31,  185,  185,   27,   25,  185,
      185,   93,   38,  109,  185,  185,  185,  185,  185,   41,
      185,  185,  185,  185,   88,  185,  185,  185,   44,  185,
       68,   48,  185,  185,  131,   90,  185,  185,  185,  110,

      185,  185,   60,  185,   98,  185,  185,   66,  185,  185,
      185,  135,  185,  185,  185,   56,  185,  185,  185,  185,
      185,   54,   82,  185,  185,  185,  185,  185,  185,  185,
       59,  185,  185,  185,  185,  118,  185,  185,  185,  185,
      185,  185,  185,  185,  185,  185,  157,  185,  185,  185,
      185,  185,  173,  185,  185,  166,  185,  185,  185,   20,
      185,  185,  185,  185,  185,  185,   89,   85,  185,  185,
      185,  185,  185,  185,  185,    6,   69,    5,  185,   49,
      126,  185,  185,  132,  108,  185,  185,   97,  185,   83,
      185,  133,  185,  136,  185,  185,  105,  185,  102,  185,

      185,  185,  185,  185,  185,  185,   47,  185,  185,  185,
      185,  185,  185,  145,  185,  185,  185,  185,  185,  185,
      185,  185,  185,  163,  164,  147,  185,  183,  185,  185,
      185,  185,   13,  185,  185,   23,  185,  122,   29,  185,
      185,  185,  185,  185,  185,   42,  185,  185,  185,  185,
       52,   84,  185,  185,  185,  185,  185,  185,  185,  185,
      185,   76,   58,  185,  185,  185,  185,  185,  185,  185,
      139,  185,  185,  185,  185,  155,  185,  160,  156,  185,
      185,  185,  184,  185,  185,  185,  185,  185,  185,  185,
       70,  185,  185,  185,   99,  185,  185,  185,  185,  185,

      127,  185,  185,  106,    7,  103,  185,  185,  185,  185,
      185,  185,   30,   18,  185,  140,  141,  185,  185,  185,
      159,  158,  161,  185,  185,  185,  124,  121,  185,  185,
      185,  128,  185,   78,   72,   75,  185,  185,   37,  185,
       73,   35,  129,  185,  185,  185,  185,  185,  185,  150,
      185,  185,  185,  185,  185,  123,  185,  185,  185,  104,
       77,   65,  185,  185,  185,  185,  185,  153,  185,  185,
      170,  185,  185,   71,  185,  185,  185,  111,  185,  185,
      185,  185,  185,  185,  185,  112,  185,  113,  148,  174,
      167,  185,  185,  185,  185,  120,   92,   74,  125,    0

    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    2,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    4,    5,    1,    1,    1,    1,    6,
        6,    1,    6,    6,    7,    1,    8,    9,   10,   11,
       12,   13,    9,    9,    9,   14,   14,    1,    1,    1,
        1,    1,    1,    1,   15,   16,   17,   18,   19,   20,
       21,    1,   22,    1,   23,   24,   25,   26,   27,   28,
        1,   29,   30,   31,   32,    1,    1,   33,    1,   34,
        1,   35,    1,    1,   36,    1,   37,   38,   39,   40,

       41,   42,   43,   44,   45,    1,   46,   47,   48,   49,
       50,   51,   52,   53,   54,   55,   56,   57,   58,   59,
       60,   61,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[62] =
    {   0,
        1,    2,    3,    4,    2,    2,    1,    5,    6,    6,
        6,    6,    6,    6,    6,    6,    6,    6,    6,    6,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    7,    1,    6,    6,    6,    6,
        6,    6,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1
    } ;

static const flex_int16_t yy_base[913] =
    {   0,
        0,    0,   59,   61,   63,   64, 1012,    0,   66,   71,
     1013,    0, 1013, 1004, 1013,   63,   26,  961,  968,  971,
      960,   21,  969,  113,  164,  945,   40,  954,   29,  958,
       31,  961,  950,  959,   42,  958,  945,    0, 1013, 1013,
      209,    0, 1013, 1013,  260,    0,   87,    0,  990,   47,
      948,  956,  941,   51,  933,  954,  954,  937,  941,  945,
       93,  940,  945,  941,   43,   60,  947,   62,  946,   80,
      926,  925,  932,  132,  137,  934,   72,  927,  932,  935,
      136,  138,  151,  139,  151,   45,  156,  934,   69,  937,
      186,  917,  192,  157,  237,  193,  209,  199,  921,  163,

      173,  926,  929,  918,  917,  928,  925,    0,  911,  914,
      924,  922,  922,  907,  905,    0,  898,  190,  905,  228,
      896,  902,  909,    0, 1013,  283, 1013, 1013, 1013, 1013,
     1013, 1013, 1013, 1013, 1013,    0,    0, 1013,  294, 1013,
     1013, 1013, 1013, 1013, 1013, 1013, 1013, 1013,    0,    0,
      909,  897,  903,  900,  899,  907,  902,  888,  904,  899,
      898,  904,  276,  890,  885,  894,  891,  879,  882,  898,
      886,    0,  878,  881,  883,  888,    0,    0,  212,  884,
        0,  883,    0,  877,  883,  882,  868,  882,  155,    0,
      867,  267,  878,  869,  864,  871,  188,  867,  871,  862,

      858,  210,  862,  865,  218,  853,  859,  855,  852,  870,
      861,  855,  851,  855,  850,  864,  221,  845,  848,  167,
      857,  847,  268,  849,    0,  857,  842,  838,    0,  238,
      845,  846,  837,  836,  843,    0,    0,  266,  842,  272,
      845,  842,  837,  833,  839,  279,  844,  285,  824,  838,
      830,  840,  277,  823,  834,  834,    0,    0,  818,  818,
      827,  829,    0,  828,  814,  811,    0,  825,  811,  823,
      805,  809,  816,  804,  809,  804,  801,  809,  801,  799,
      330,    0,  335,    0,  816,  799,  810,  810,  796,  789,
      793,  796,  798,  795,  794,  792,    0,    0,    0,    0,

      797,  803,    0,  784,  789,  792,    0,  788,  798,  783,
      795,  777,  788,  791,    0,    0,    0,  785,  780,    0,
      772,  773,  780,  787,  772,  778,  774,  767,  782,  771,
        0,  764,  761,    0,  776,  776,  770,  752,    0,  756,
      762,    0,  760,  753,  762,  761,    0,  751,  751,  766,
      754,    0,  748,  745,    0,  762,  747,  759,  753,  750,
      739,  738,    0,  742,  744,    0,  755,  746,  749,  731,
      738,  730,  733,    0,  735,  286,    0,  737,  738,  735,
      734,  728,    0,  733,  728,    0,  735,  720,  729,    0,
      718,  731,    0,  275,  729,  729,  715,  722,  317,    0,

      723,  728,    0,  727,  709,    0,  721,  713,  709,  704,
      709,  707,  719,  705,  709,  704,  707,  710,  709,  704,
      693, 1013, 1013, 1013, 1013,  694,  701,  696,  699,    0,
      340,  698,  689,  705,    0,  697,  692,  701,    0,  700,
      699,  688,  697,    0,  696,  692,  203,  694,  677,  674,
      691,  690,  673,  678,    0,  680,  686,  681,  671,    0,
      679,  674,    0,    0,  664,    0,  664,  679,  665,  677,
      653,  665,  654,  655,  664,  661,  670,  651,  645,    0,
      667,  663,  655,  654,  646,  321,  649,  661,  280,  660,
      643,  641,  653,  648,    0,  651,    0,  636,  651,  642,

      641,  633,  636,  630,  647,  642,  641,  626,  639,    0,
      638,  641,  623,  635,  622,  627,  622,  622,  626,  310,
      629,  624,  316,  627,    0,  629,  611,  612,  623,  608,
        0,  608,  608,  605,  610,  605,  617,  601,  606,    0,
      604,  612,    0,  603,  596,  601,    0,    0,    0,    0,
      611,  608,  593,    0,    0,    0,    0,  593,  595,    0,
        0,  607,  590,  597,    0,  591,  603,    0,    0,  589,
      588,    0,    0,    0,  578,  581,  598,  578,  588,    0,
      583,  578,  576,  579,    0,  574,  578,  579,    0,  571,
        0,    0,  587,  582,    0,    0,  569,  576,  567,    0,

      570,  562,    0,  567,    0,  562,  578,    0,  564,  576,
      571,    0,  556,  557,  572,    0,  554,  552,  562,  550,
      562,    0,    0,  555,  552,  551,  546,  548,  561,  552,
        0,  553,  552,  553,  556,    0,  551,  541,  536,  540,
      543,  542,  546,  535,  547,  542,    0,  537,  542,  531,
      530,  535,  541,  533,  528,  538,  518,  519,  522,    0,
      517,  526,  519,  514,  508,  516,    0,    0,  521,  518,
      519,  521,  507,  518,  509,    0,    0,    0,  501,    0,
        0,  503,  512,    0,    0,  516,  504,    0,  505,    0,
      504,    0,  509,    0,  496,  492,  506,  509,  504,  494,

      506,  484,  492,  495,  479,  490,    0,  492,  488,  480,
      494,  478,  479,    0,  476,  480,  474,  474,  474,  479,
      471,  467,  482,    0,    0,    0,  468,    0,  480,  462,
      459,  460,    0,  453,  454,    0,  444,    0,    0,  449,
       27,   56,  136,  234,  244,    0,  284,  282,  291,  305,
        0,    0,  320,  309,  310,  319,  313,  311,  315,  320,
      322,    0,    0,  329,  324,  328,  325,  343,  344,  341,
      329,  330,  348,  337,  342,    0,  334,    0,    0,  348,
      336,  336,    0,  337,  343,  336,  337,  341,  347,  345,
        0,  344,  344,  343,    0,  347,  345,  349,  364,  347,

        0,  357,  353,    0,    0,    0,  368,  364,  361,  367,
      364,  359,    0,    0,  367,    0,    0,  361,  363,  361,
        0,    0,    0,  366,  367,  372,    0,    0,  385,  365,
      383,    0,  380,    0,    0,    0,  389,  372,    0,  370,
        0,    0,    0,  380,  387,  391,  391,  396,  389,    0,
      394,  386,  387,  395,  386,    0,  385,  386,  389,    0,
        0,    0,  399,  390,  392,  393,  397,    0,  399,  400,
        0,  397,  395,    0,  399,  398,  398,    0,  409,  407,
      414,  415,  409,  407,  411,    0,  417,    0,    0,    0,
        0,  405,  415,  407,  411,    0,    0,    0,    0, 1013,

      466,  473,  480,  487,  494,  500,  507,  513,  476,  477,
      478,  479
    } ;

static const flex_int16_t yy_def[913] =
    {   0,
      900,    1,  901,  901,  902,  902,  900,  903,  900,  900,
      900,  904,  900,  903,  900,  903,  903,  903,  903,  903,
      903,  903,  903,  900,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  905,  900,  900,
      906,  907,  900,  900,  908,  903,  900,  904,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,

      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  905,  900,  900,  900,  900,  900,  900,
      900,  900,  900,  900,  900,  909,  907,  900,  900,  900,
      900,  900,  900,  900,  900,  900,  900,  900,  910,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,

      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      900,  911,  900,  912,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,

      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,

      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  900,  900,  900,  900,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,

      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,

      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,

      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,

      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,  903,
      903,  903,  903,  903,  903,  903,  903,  903,  903,    0,

      900,  900,  900,  900,  900,  900,  900,  900,  900,  900,
      900,  900
    } ;

static const flex_int16_t yy_nxt[1075] =
    {   0,
        8,    9,   10,   11,   12,   13,   14,   15,    8,    8,
        8,    8,    8,    8,    8,    8,   16,    8,   17,    8,
        8,   18,   19,   20,    8,    8,    8,   21,    8,   22,
       23,    8,    8,    8,   24,    8,   25,   26,   27,   28,
       29,   30,    8,    8,   31,   32,    8,    8,    8,   33,
        8,    8,   34,   35,    8,    8,   36,   37,    8,    8,
        8,   39,   40,   39,   40,   43,   43,   47,   47,   50,
       44,   44,   47,   47,   52,   58,  109,  112,   53,  115,
       59,  791,  120,  167,  116,  151,  110,  113,   47,   47,
      156,  212,  168,   41,  213,   41,  121,   45,   45,  792,

      152,   61,   61,   61,   61,   61,   61,  157,  187,  172,
      169,  173,   51,   46,  170,  188,  175,  217,  218,   46,
      176,   61,   61,   61,   61,   61,   61,   62,   63,   64,
       65,   66,   46,   67,   68,   69,   70,   71,   72,   73,
       74,   75,   76,   77,   78,   79,   80,   46,   46,   81,
       82,   83,   84,   85,   86,   87,   88,   89,   90,   91,
       92,   93,   94,   95,   46,   96,   97,   98,   99,  100,
      101,  102,   46,  103,  104,  180,  181,  183,  195,  204,
      184,  185,  192,  205,  193,  182,  194,  197,  206,  793,
      198,  322,  214,  196,  199,  200,  215,  201,  207,  254,

      202,  208,  209,  255,  230,  210,  203,  231,  323,  211,
      105,  232,  106,  256,  358,  359,  107,  126,  126,  126,
      126,  126,  220,  257,  221,  222,  223,  224,  226,  240,
      272,  241,  227,  242,  243,  249,  244,  245,  331,  563,
      332,  228,  250,  251,  273,  127,  128,  229,  129,  130,
      131,  252,  313,  246,  341,  564,  314,  132,  337,  247,
      338,  133,  354,  134,  248,  135,  275,  136,  139,  139,
      139,  139,  139,  233,  342,  355,  276,  234,  368,  277,
      235,  236,  369,  794,  237,  297,  298,  299,  300,  238,
      239,  281,  281,  281,  281,  281,  140,  141,  795,  142,

      143,  144,  283,  283,  283,  283,  283,  325,  145,  362,
      375,  378,  146,  397,  147,  376,  148,  326,  149,  363,
      379,  385,  388,  389,  601,  497,  386,  511,  796,  512,
      398,  797,  390,  602,  798,  391,  498,  392,  422,  422,
      422,  422,  422,  424,  424,  424,  424,  424,  517,  547,
      548,  549,  550,  630,  631,  518,  519,  597,  799,  634,
      800,  801,  802,  803,  804,  805,  806,  520,  635,  521,
      522,  523,  807,  598,  808,  809,  810,  811,  812,  813,
      814,  815,  816,  817,  818,  819,  820,  821,  822,  823,
      824,  825,  826,  827,  828,  829,  830,  831,  832,  833,

      834,  835,  836,  837,  838,  839,  840,  841,  842,  843,
      844,  845,  846,  847,  848,  849,  850,  851,  852,  853,
      854,  855,  856,  857,  858,  859,  860,  861,  862,  863,
      864,  865,  866,  867,  868,  869,  870,  871,  872,  873,
      874,  875,  876,  877,  878,  879,  880,  881,  882,  883,
      884,  885,  886,  887,  888,  889,  890,  891,  892,  893,
      894,  895,  896,  897,  898,  899,   38,   38,   38,   38,
       38,   38,   38,   42,   42,   42,   42,   42,   42,   42,
       46,  282,  284,  423,  425,   46,   46,   48,   48,  790,
       48,   48,   48,   48,  124,  124,  789,  788,  124,  124,

      125,  125,  787,  125,  125,  125,  125,  137,  137,  786,
      137,  785,  137,  138,  138,  784,  138,  138,  138,  138,
      783,  782,  781,  780,  779,  778,  777,  776,  775,  774,
      773,  772,  771,  770,  769,  768,  767,  766,  765,  764,
      763,  762,  761,  760,  759,  758,  757,  756,  755,  754,
      753,  752,  751,  750,  749,  748,  747,  746,  745,  744,
      743,  742,  741,  740,  739,  738,  737,  736,  735,  734,
      733,  732,  731,  730,  729,  728,  727,  726,  725,  724,
      723,  722,  721,  720,  719,  718,  717,  716,  715,  714,
      713,  712,  711,  710,  709,  708,  707,  706,  705,  704,

      703,  702,  701,  700,  699,  698,  697,  696,  695,  694,
      693,  692,  691,  690,  689,  688,  687,  686,  685,  684,
      683,  682,  681,  680,  679,  678,  677,  676,  675,  674,
      673,  672,  671,  670,  669,  668,  667,  666,  665,  664,
      663,  662,  661,  660,  659,  658,  657,  656,  655,  654,
      653,  652,  651,  650,  649,  648,  647,  646,  645,  644,
      643,  642,  641,  640,  639,  638,  637,  636,  633,  632,
      629,  628,  627,  626,  625,  624,  623,  622,  621,  620,
      619,  618,  617,  616,  615,  614,  613,  612,  611,  610,
      609,  608,  607,  606,  605,  604,  603,  600,  599,  596,

      595,  594,  593,  592,  591,  590,  589,  588,  587,  586,
      585,  584,  583,  582,  581,  580,  579,  578,  577,  576,
      575,  574,  573,  572,  571,  570,  569,  568,  567,  566,
      565,  562,  561,  560,  559,  558,  557,  556,  555,  554,
      553,  552,  551,  546,  545,  544,  543,  542,  541,  540,
      539,  538,  537,  536,  535,  534,  533,  532,  531,  530,
      529,  528,  527,  526,  525,  524,  516,  515,  514,  513,
      510,  509,  508,  507,  506,  505,  504,  503,  502,  501,
      500,  499,  496,  495,  494,  493,  492,  491,  490,  489,
      488,  487,  486,  485,  484,  483,  482,  481,  480,  479,

      478,  477,  476,  475,  474,  473,  472,  471,  470,  469,
      468,  467,  466,  465,  464,  463,  462,  461,  460,  459,
      458,  457,  456,  455,  454,  453,  452,  451,  450,  449,
      448,  447,  446,  445,  444,  443,  442,  441,  440,  439,
      438,  437,  436,  435,  434,  433,  432,  431,  430,  429,
      428,  427,  426,  421,  420,  419,  418,  417,  416,  415,
      414,  413,  412,  411,  410,  409,  408,  407,  406,  405,
      404,  403,  402,  401,  400,  399,  396,  395,  394,  393,
      387,  384,  383,  382,  381,  380,  377,  374,  373,  372,
      371,  370,  367,  366,  365,  364,  361,  360,  357,  356,

      353,  352,  351,  350,  349,  348,  347,  346,  345,  344,
      343,  340,  339,  336,  335,  334,  333,  330,  329,  328,
      327,  324,  321,  320,  319,  318,  317,  316,  315,  312,
      311,  310,  309,  308,  307,  306,  305,  304,  303,  302,
      301,  296,  295,  294,  293,  292,  291,  290,  289,  288,
      287,  286,  285,  280,  279,  278,  274,  271,  270,  269,
      268,  267,  266,  265,  264,  263,  262,  261,  260,  259,
      258,  253,  225,  219,  216,  191,  190,  189,  186,  179,
      178,  177,  174,  171,  166,  165,  164,  163,  162,  161,
      160,  159,  158,  155,  154,  153,  150,  123,  122,  119,

      118,  117,  114,  111,  108,   60,   57,   56,   55,   54,
       49,  900,    7,  900,  900,  900,  900,  900,  900,  900,
      900,  900,  900,  900,  900,  900,  900,  900,  900,  900,
      900,  900,  900,  900,  900,  900,  900,  900,  900,  900,
      900,  900,  900,  900,  900,  900,  900,  900,  900,  900,
      900,  900,  900,  900,  900,  900,  900,  900,  900,  900,
      900,  900,  900,  900,  900,  900,  900,  900,  900,  900,
      900,  900,  900,  900
    } ;

static const flex_int16_t yy_chk[1075] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    3,    3,    4,    4,    5,    6,    9,    9,   16,
        5,    6,   10,   10,   17,   22,   27,   29,   17,   31,
       22,  741,   35,   65,   31,   50,   27,   29,   47,   47,
       54,   86,   65,    3,   86,    4,   35,    5,    6,  742,

       50,   61,   61,   61,   61,   61,   61,   54,   77,   68,
       66,   68,   16,   24,   66,   77,   70,   89,   89,   24,
       70,   24,   24,   24,   24,   24,   24,   24,   24,   24,
       24,   24,   24,   24,   24,   24,   24,   24,   24,   24,
       24,   24,   24,   24,   24,   24,   24,   24,   24,   24,
       24,   24,   24,   24,   24,   24,   24,   24,   24,   24,
       24,   24,   24,   24,   24,   24,   24,   24,   24,   24,
       24,   24,   24,   24,   25,   74,   74,   75,   82,   84,
       75,   75,   81,   84,   81,   74,   81,   83,   84,  743,
       83,  189,   87,   82,   83,   83,   87,   83,   85,  100,

       83,   85,   85,  100,   94,   85,   83,   94,  189,   85,
       25,   94,   25,  101,  220,  220,   25,   41,   41,   41,
       41,   41,   91,  101,   91,   91,   91,   91,   93,   96,
      118,   96,   93,   96,   96,   98,   96,   96,  197,  447,
      197,   93,   98,   98,  118,   41,   41,   93,   41,   41,
       41,   98,  179,   97,  205,  447,  179,   41,  202,   97,
      202,   41,  217,   41,   97,   41,  120,   41,   45,   45,
       45,   45,   45,   95,  205,  217,  120,   95,  230,  120,
       95,   95,  230,  744,   95,  163,  163,  163,  163,   95,
       95,  126,  126,  126,  126,  126,   45,   45,  745,   45,

       45,   45,  139,  139,  139,  139,  139,  192,   45,  223,
      238,  240,   45,  253,   45,  238,   45,  192,   45,  223,
      240,  246,  248,  248,  489,  376,  246,  394,  747,  394,
      253,  748,  248,  489,  749,  248,  376,  248,  281,  281,
      281,  281,  281,  283,  283,  283,  283,  283,  399,  431,
      431,  431,  431,  520,  520,  399,  399,  486,  750,  523,
      753,  754,  755,  756,  757,  758,  759,  399,  523,  399,
      399,  399,  760,  486,  761,  764,  765,  766,  767,  768,
      769,  770,  771,  772,  773,  774,  775,  777,  780,  781,
      782,  784,  785,  786,  787,  788,  789,  790,  792,  793,

      794,  796,  797,  798,  799,  800,  802,  803,  807,  808,
      809,  810,  811,  812,  815,  818,  819,  820,  824,  825,
      826,  829,  830,  831,  833,  837,  838,  840,  844,  845,
      846,  847,  848,  849,  851,  852,  853,  854,  855,  857,
      858,  859,  863,  864,  865,  866,  867,  869,  870,  872,
      873,  875,  876,  877,  879,  880,  881,  882,  883,  884,
      885,  887,  892,  893,  894,  895,  901,  901,  901,  901,
      901,  901,  901,  902,  902,  902,  902,  902,  902,  902,
      903,  909,  910,  911,  912,  903,  903,  904,  904,  740,
      904,  904,  904,  904,  905,  905,  737,  735,  905,  905,

      906,  906,  734,  906,  906,  906,  906,  907,  907,  732,
      907,  731,  907,  908,  908,  730,  908,  908,  908,  908,
      729,  727,  723,  722,  721,  720,  719,  718,  717,  716,
      715,  713,  712,  711,  710,  709,  708,  706,  705,  704,
      703,  702,  701,  700,  699,  698,  697,  696,  695,  693,
      691,  689,  687,  686,  683,  682,  679,  675,  674,  673,
      672,  671,  670,  669,  666,  665,  664,  663,  662,  661,
      659,  658,  657,  656,  655,  654,  653,  652,  651,  650,
      649,  648,  646,  645,  644,  643,  642,  641,  640,  639,
      638,  637,  635,  634,  633,  632,  630,  629,  628,  627,

      626,  625,  624,  621,  620,  619,  618,  617,  615,  614,
      613,  611,  610,  609,  607,  606,  604,  602,  601,  599,
      598,  597,  594,  593,  590,  588,  587,  586,  584,  583,
      582,  581,  579,  578,  577,  576,  575,  571,  570,  567,
      566,  564,  563,  562,  559,  558,  553,  552,  551,  546,
      545,  544,  542,  541,  539,  538,  537,  536,  535,  534,
      533,  532,  530,  529,  528,  527,  526,  524,  522,  521,
      519,  518,  517,  516,  515,  514,  513,  512,  511,  509,
      508,  507,  506,  505,  504,  503,  502,  501,  500,  499,
      498,  496,  494,  493,  492,  491,  490,  488,  487,  485,

      484,  483,  482,  481,  479,  478,  477,  476,  475,  474,
      473,  472,  471,  470,  469,  468,  467,  465,  462,  461,
      459,  458,  457,  456,  454,  453,  452,  451,  450,  449,
      448,  446,  445,  443,  442,  441,  440,  438,  437,  436,
      434,  433,  432,  429,  428,  427,  426,  421,  420,  419,
      418,  417,  416,  415,  414,  413,  412,  411,  410,  409,
      408,  407,  405,  404,  402,  401,  398,  397,  396,  395,
      392,  391,  389,  388,  387,  385,  384,  382,  381,  380,
      379,  378,  375,  373,  372,  371,  370,  369,  368,  367,
      365,  364,  362,  361,  360,  359,  358,  357,  356,  354,

      353,  351,  350,  349,  348,  346,  345,  344,  343,  341,
      340,  338,  337,  336,  335,  333,  332,  330,  329,  328,
      327,  326,  325,  324,  323,  322,  321,  319,  318,  314,
      313,  312,  311,  310,  309,  308,  306,  305,  304,  302,
      301,  296,  295,  294,  293,  292,  291,  290,  289,  288,
      287,  286,  285,  280,  279,  278,  277,  276,  275,  274,
      273,  272,  271,  270,  269,  268,  266,  265,  264,  262,
      261,  260,  259,  256,  255,  254,  252,  251,  250,  249,
      247,  245,  244,  243,  242,  241,  239,  235,  234,  233,
      232,  231,  228,  227,  226,  224,  222,  221,  219,  218,

      216,  215,  214,  213,  212,  211,  210,  209,  208,  207,
      206,  204,  203,  201,  200,  199,  198,  196,  195,  194,
      193,  191,  188,  187,  186,  185,  184,  182,  180,  176,
      175,  174,  173,  171,  170,  169,  168,  167,  166,  165,
      164,  162,  161,  160,  159,  158,  157,  156,  155,  154,
      153,  152,  151,  123,  122,  121,  119,  117,  115,  114,
      113,  112,  111,  110,  109,  107,  106,  105,  104,  103,
      102,   99,   92,   90,   88,   80,   79,   78,   76,   73,
       72,   71,   69,   67,   64,   63,   62,   60,   59,   58,
       57,   56,   55,   53,   52,   51,   49,   37,   36,   34,

       33,   32,   30,   28,   26,   23,   21,   20,   19,   18,
       14,    7,  900,  900,  900,  900,  900,  900,  900,  900,
      900,  900,  900,  900,  900,  900,  900,  900,  900,  900,
      900,  900,  900,  900,  900,  900,  900,  900,  900,  900,
      900,  900,  900,  900,  900,  900,  900,  900,  900,  900,
      900,  900,  900,  900,  900,  900,  900,  900,  900,  900,
      900,  900,  900,  900,  900,  900,  900,  900,  900,  900,
      900,  900,  900,  900
    } ;

/* Table of booleans, true if rule could match eol. */
static const flex_int32_t yy_rule_can_match_eol[218] =
    {   0,
0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0,     };

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "lexssh.l"

#line 43 "lexssh.l"
/* Defines if the comments are printed or not */
extern int strip_level;

/* #define YY_DECL yylex (YYSTYPE *lvalp);*/

int yylex (void);
void yyerror (const char *);

/* Initilizes the obstacks */
void sshlex_initialize (void);

/* Obstack for strings reading */
static struct obstack string_stack;

/* The file we scan. */
const char * sshfilename;

#define LATEX_SYM_RETURN(Str)	\
   yylval.string = (unsigned char *) xstrdup (Str) ; return tLATEXSYMBOL ;

#define RETURN_FACE(_f_)\
   {yylval.face = _f_ ; return tFACE ;}

#define RETURN_FFLAGS(_f_)\
   {yylval.fflags = _f_ ; return tFFLAGS ;}

#line 1339 "lexssh.c"

#line 1341 "lexssh.c"

#define INITIAL 0
#define STATE_STRING 1
#define STATE_REGEXP 2

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals ( void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( void );

int yyget_debug ( void );

void yyset_debug ( int debug_flag  );

YY_EXTRA_TYPE yyget_extra ( void );

void yyset_extra ( YY_EXTRA_TYPE user_defined  );

FILE *yyget_in ( void );

void yyset_in  ( FILE * _in_str  );

FILE *yyget_out ( void );

void yyset_out  ( FILE * _out_str  );

			int yyget_leng ( void );

char *yyget_text ( void );

int yyget_lineno ( void );

void yyset_lineno ( int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( void );
#else
extern int yywrap ( void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
    static void yyunput ( int c, char *buf_ptr  );
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( void );
#else
static int input ( void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	{
#line 82 "lexssh.l"


#line 1563 "lexssh.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 901 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1013 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

		if ( yy_act != YY_END_OF_BUFFER && yy_rule_can_match_eol[yy_act] )
			{
			int yyl;
			for ( yyl = 0; yyl < yyleng; ++yyl )
				if ( yytext[yyl] == '\n' )
					
    yylineno++;
;
			}

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 84 "lexssh.l"
{ ; }
	YY_BREAK
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 85 "lexssh.l"
{ ; }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 87 "lexssh.l"
{ BEGIN STATE_STRING; }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 88 "lexssh.l"
{ BEGIN STATE_REGEXP; }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 90 "lexssh.l"
LATEX_SYM_RETURN ("\042");
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 91 "lexssh.l"
LATEX_SYM_RETURN ("\044");
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 92 "lexssh.l"
LATEX_SYM_RETURN ("\047");
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 93 "lexssh.l"
LATEX_SYM_RETURN ("\100");
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 94 "lexssh.l"
LATEX_SYM_RETURN ("\101");
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 95 "lexssh.l"
LATEX_SYM_RETURN ("\102");
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 96 "lexssh.l"
LATEX_SYM_RETURN ("\103");
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 97 "lexssh.l"
LATEX_SYM_RETURN ("\104");
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 98 "lexssh.l"
LATEX_SYM_RETURN ("\105");
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 99 "lexssh.l"
LATEX_SYM_RETURN ("\106");
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 100 "lexssh.l"
LATEX_SYM_RETURN ("\107");
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 101 "lexssh.l"
LATEX_SYM_RETURN ("\110");
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 102 "lexssh.l"
LATEX_SYM_RETURN ("\111");
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 103 "lexssh.l"
LATEX_SYM_RETURN ("\112");
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 104 "lexssh.l"
LATEX_SYM_RETURN ("\113");
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 105 "lexssh.l"
LATEX_SYM_RETURN ("\114");
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 106 "lexssh.l"
LATEX_SYM_RETURN ("\115");
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 107 "lexssh.l"
LATEX_SYM_RETURN ("\116");
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 108 "lexssh.l"
LATEX_SYM_RETURN ("\117");
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 109 "lexssh.l"
LATEX_SYM_RETURN ("\120");
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 110 "lexssh.l"
LATEX_SYM_RETURN ("\121");
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 111 "lexssh.l"
LATEX_SYM_RETURN ("\122");
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 112 "lexssh.l"
LATEX_SYM_RETURN ("\123");
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 113 "lexssh.l"
LATEX_SYM_RETURN ("\124");
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 114 "lexssh.l"
LATEX_SYM_RETURN ("\125");
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 115 "lexssh.l"
LATEX_SYM_RETURN ("\126");
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 116 "lexssh.l"
LATEX_SYM_RETURN ("\127");
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 117 "lexssh.l"
LATEX_SYM_RETURN ("\130");
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 118 "lexssh.l"
LATEX_SYM_RETURN ("\131");
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 119 "lexssh.l"
LATEX_SYM_RETURN ("\132");
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 120 "lexssh.l"
LATEX_SYM_RETURN ("\134");
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 121 "lexssh.l"
LATEX_SYM_RETURN ("\136");
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 122 "lexssh.l"
LATEX_SYM_RETURN ("\140");
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 123 "lexssh.l"
LATEX_SYM_RETURN ("\141");
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 124 "lexssh.l"
LATEX_SYM_RETURN ("\142");
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 125 "lexssh.l"
LATEX_SYM_RETURN ("\143");
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 126 "lexssh.l"
LATEX_SYM_RETURN ("\144");
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 127 "lexssh.l"
LATEX_SYM_RETURN ("\145");
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 128 "lexssh.l"
LATEX_SYM_RETURN ("\146");
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 129 "lexssh.l"
LATEX_SYM_RETURN ("\147");
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 130 "lexssh.l"
LATEX_SYM_RETURN ("\150");
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 131 "lexssh.l"
LATEX_SYM_RETURN ("\151");
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 132 "lexssh.l"
LATEX_SYM_RETURN ("\152");
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 133 "lexssh.l"
LATEX_SYM_RETURN ("\153");
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 134 "lexssh.l"
LATEX_SYM_RETURN ("\154");
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 135 "lexssh.l"
LATEX_SYM_RETURN ("\155");
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 136 "lexssh.l"
LATEX_SYM_RETURN ("\156");
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 137 "lexssh.l"
LATEX_SYM_RETURN ("\157");
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 138 "lexssh.l"
LATEX_SYM_RETURN ("\160");
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 139 "lexssh.l"
LATEX_SYM_RETURN ("\161");
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 140 "lexssh.l"
LATEX_SYM_RETURN ("\162");
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 141 "lexssh.l"
LATEX_SYM_RETURN ("\163");
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 142 "lexssh.l"
LATEX_SYM_RETURN ("\164");
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 143 "lexssh.l"
LATEX_SYM_RETURN ("\165");
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 144 "lexssh.l"
LATEX_SYM_RETURN ("\166");
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 145 "lexssh.l"
LATEX_SYM_RETURN ("\167");
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 146 "lexssh.l"
LATEX_SYM_RETURN ("\170");
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 147 "lexssh.l"
LATEX_SYM_RETURN ("\171");
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 148 "lexssh.l"
LATEX_SYM_RETURN ("\172");
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 149 "lexssh.l"
LATEX_SYM_RETURN ("\176");
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 150 "lexssh.l"
LATEX_SYM_RETURN ("\241");
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 151 "lexssh.l"
LATEX_SYM_RETURN ("\242");
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 152 "lexssh.l"
LATEX_SYM_RETURN ("\243");
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 153 "lexssh.l"
LATEX_SYM_RETURN ("\245");
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 154 "lexssh.l"
LATEX_SYM_RETURN ("\246");
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 155 "lexssh.l"
LATEX_SYM_RETURN ("\247");
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 156 "lexssh.l"
LATEX_SYM_RETURN ("\250");
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 157 "lexssh.l"
LATEX_SYM_RETURN ("\251");
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 158 "lexssh.l"
LATEX_SYM_RETURN ("\252");
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 159 "lexssh.l"
LATEX_SYM_RETURN ("\253");
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 160 "lexssh.l"
LATEX_SYM_RETURN ("\254");
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 161 "lexssh.l"
LATEX_SYM_RETURN ("\255");
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 162 "lexssh.l"
LATEX_SYM_RETURN ("\256");
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 163 "lexssh.l"
LATEX_SYM_RETURN ("\257");
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 164 "lexssh.l"
LATEX_SYM_RETURN ("\260");
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 165 "lexssh.l"
LATEX_SYM_RETURN ("\261");
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 166 "lexssh.l"
LATEX_SYM_RETURN ("\263");
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 167 "lexssh.l"
LATEX_SYM_RETURN ("\264");
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 168 "lexssh.l"
LATEX_SYM_RETURN ("\265");
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 169 "lexssh.l"
LATEX_SYM_RETURN ("\266");
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 170 "lexssh.l"
LATEX_SYM_RETURN ("\267");
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 171 "lexssh.l"
LATEX_SYM_RETURN ("\270");
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 172 "lexssh.l"
LATEX_SYM_RETURN ("\271");
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 173 "lexssh.l"
LATEX_SYM_RETURN ("\272");
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 174 "lexssh.l"
LATEX_SYM_RETURN ("\273");
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 175 "lexssh.l"
LATEX_SYM_RETURN ("\274");
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 176 "lexssh.l"
LATEX_SYM_RETURN ("\276");
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 177 "lexssh.l"
LATEX_SYM_RETURN ("\277");
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 178 "lexssh.l"
LATEX_SYM_RETURN ("\300");
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 179 "lexssh.l"
LATEX_SYM_RETURN ("\301");
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 180 "lexssh.l"
LATEX_SYM_RETURN ("\302");
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 181 "lexssh.l"
LATEX_SYM_RETURN ("\303");
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 182 "lexssh.l"
LATEX_SYM_RETURN ("\304");
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 183 "lexssh.l"
LATEX_SYM_RETURN ("\305");
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 184 "lexssh.l"
LATEX_SYM_RETURN ("\306");
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 185 "lexssh.l"
LATEX_SYM_RETURN ("\307");
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 186 "lexssh.l"
LATEX_SYM_RETURN ("\310");
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 187 "lexssh.l"
LATEX_SYM_RETURN ("\311");
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 188 "lexssh.l"
LATEX_SYM_RETURN ("\312");
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 189 "lexssh.l"
LATEX_SYM_RETURN ("\313");
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 190 "lexssh.l"
LATEX_SYM_RETURN ("\314");
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 191 "lexssh.l"
LATEX_SYM_RETURN ("\315");
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 192 "lexssh.l"
LATEX_SYM_RETURN ("\316");
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 193 "lexssh.l"
LATEX_SYM_RETURN ("\317");
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 194 "lexssh.l"
LATEX_SYM_RETURN ("\320");
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 195 "lexssh.l"
LATEX_SYM_RETURN ("\321");
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 196 "lexssh.l"
LATEX_SYM_RETURN ("\322");
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 197 "lexssh.l"
LATEX_SYM_RETURN ("\324");
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 198 "lexssh.l"
LATEX_SYM_RETURN ("\324");
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 199 "lexssh.l"
LATEX_SYM_RETURN ("\325");
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 200 "lexssh.l"
LATEX_SYM_RETURN ("\326");
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 201 "lexssh.l"
LATEX_SYM_RETURN ("\327");
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 202 "lexssh.l"
LATEX_SYM_RETURN ("\330");
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 203 "lexssh.l"
LATEX_SYM_RETURN ("\331");
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 204 "lexssh.l"
LATEX_SYM_RETURN ("\332");
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 205 "lexssh.l"
LATEX_SYM_RETURN ("\333");
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 206 "lexssh.l"
LATEX_SYM_RETURN ("\334");
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 207 "lexssh.l"
LATEX_SYM_RETURN ("\335");
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 208 "lexssh.l"
LATEX_SYM_RETURN ("\336");
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 209 "lexssh.l"
LATEX_SYM_RETURN ("\337");
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 210 "lexssh.l"
LATEX_SYM_RETURN ("\340");
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 211 "lexssh.l"
LATEX_SYM_RETURN ("\341");
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 212 "lexssh.l"
LATEX_SYM_RETURN ("\342");
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 213 "lexssh.l"
LATEX_SYM_RETURN ("\342");
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 214 "lexssh.l"
LATEX_SYM_RETURN ("\344");
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 215 "lexssh.l"
LATEX_SYM_RETURN ("\345");
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 216 "lexssh.l"
LATEX_SYM_RETURN ("\351");
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 217 "lexssh.l"
LATEX_SYM_RETURN ("\353");
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 218 "lexssh.l"
LATEX_SYM_RETURN ("\361");
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 219 "lexssh.l"
LATEX_SYM_RETURN ("\362");
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 220 "lexssh.l"
LATEX_SYM_RETURN ("\371");
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 221 "lexssh.l"
LATEX_SYM_RETURN ("\373");
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 223 "lexssh.l"
{
  int value = yytext[1] - '0';
  char *cursor = yytext + 2;

  while (*cursor)
    value = 8 * value + *cursor++ - '0';
  yylval.integer = value;
  return tBACK_REF;
}
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 233 "lexssh.l"
return tA2PS;
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 234 "lexssh.l"
return tALPHABET;
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 235 "lexssh.l"
return tALPHABETS;
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 236 "lexssh.l"
return tANCESTORS;
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 237 "lexssh.l"
return tARE;
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 238 "lexssh.l"
return tBY;
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 239 "lexssh.l"
return tCASE;
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 240 "lexssh.l"
return tCLOSERS;
	YY_BREAK
case 146:
YY_RULE_SETUP
#line 241 "lexssh.l"
return tCCHAR;
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 242 "lexssh.l"
return tCSTRING;
	YY_BREAK
case 148:
YY_RULE_SETUP
#line 243 "lexssh.l"
return tDOCUMENTATION;
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 244 "lexssh.l"
return tEND;
	YY_BREAK
case 150:
YY_RULE_SETUP
#line 245 "lexssh.l"
return tEXCEPTIONS;
	YY_BREAK
case 151:
YY_RULE_SETUP
#line 246 "lexssh.l"
return tFIRST;
	YY_BREAK
case 152:
YY_RULE_SETUP
#line 247 "lexssh.l"
return tIN;
	YY_BREAK
case 153:
YY_RULE_SETUP
#line 248 "lexssh.l"
{ yylval.sensitiveness = case_insensitive ;
		   return tSENSITIVENESS;
		}
	YY_BREAK
case 154:
YY_RULE_SETUP
#line 251 "lexssh.l"
return tIS;
	YY_BREAK
case 155:
YY_RULE_SETUP
#line 252 "lexssh.l"
return tKEYWORDS;
	YY_BREAK
case 156:
YY_RULE_SETUP
#line 253 "lexssh.l"
return tREQUIRES;
	YY_BREAK
case 157:
YY_RULE_SETUP
#line 254 "lexssh.l"
return tSECOND;
	YY_BREAK
case 158:
YY_RULE_SETUP
#line 255 "lexssh.l"
{ yylval.sensitiveness = case_sensitive ;
	          return tSENSITIVENESS;
		}
	YY_BREAK
case 159:
YY_RULE_SETUP
#line 258 "lexssh.l"
return tOPERATORS;
	YY_BREAK
case 160:
YY_RULE_SETUP
#line 259 "lexssh.l"
return tOPTIONAL;
	YY_BREAK
case 161:
YY_RULE_SETUP
#line 260 "lexssh.l"
return tSEQUENCES;
	YY_BREAK
case 162:
YY_RULE_SETUP
#line 261 "lexssh.l"
return tSTYLE;
	YY_BREAK
case 163:
YY_RULE_SETUP
#line 262 "lexssh.l"
return tVERSION;
	YY_BREAK
case 164:
YY_RULE_SETUP
#line 263 "lexssh.l"
return tWRITTEN;
	YY_BREAK
case 165:
YY_RULE_SETUP
#line 265 "lexssh.l"
RETURN_FACE (Plain)
	YY_BREAK
case 166:
YY_RULE_SETUP
#line 266 "lexssh.l"
RETURN_FACE (Keyword)
	YY_BREAK
case 167:
YY_RULE_SETUP
#line 267 "lexssh.l"
RETURN_FACE (Keyword_strong)
	YY_BREAK
case 168:
YY_RULE_SETUP
#line 268 "lexssh.l"
RETURN_FACE (Error)
	YY_BREAK
case 169:
YY_RULE_SETUP
#line 269 "lexssh.l"
RETURN_FACE (Label)
	YY_BREAK
case 170:
YY_RULE_SETUP
#line 270 "lexssh.l"
RETURN_FACE (Label_strong)
	YY_BREAK
case 171:
YY_RULE_SETUP
#line 271 "lexssh.l"
RETURN_FACE (String)
	YY_BREAK
case 172:
YY_RULE_SETUP
#line 272 "lexssh.l"
RETURN_FACE (Symbol)
	YY_BREAK
case 173:
YY_RULE_SETUP
#line 273 "lexssh.l"
{	/* Strip if required */
		  if ((strip_level == 1) || (strip_level == 3))
		    RETURN_FFLAGS (ff_Invisible)
		  else
		    RETURN_FACE (Comment)
		}
	YY_BREAK
case 174:
YY_RULE_SETUP
#line 279 "lexssh.l"
{	/* Strip if required */
		  if ((strip_level == 2) || (strip_level == 3))
		    RETURN_FFLAGS (ff_Invisible)
		  else
		    RETURN_FACE (Comment_strong)
		}
	YY_BREAK
case 175:
YY_RULE_SETUP
#line 286 "lexssh.l"
RETURN_FFLAGS (ff_Tag1)
	YY_BREAK
case 176:
YY_RULE_SETUP
#line 287 "lexssh.l"
RETURN_FFLAGS (ff_Tag2)
	YY_BREAK
case 177:
YY_RULE_SETUP
#line 288 "lexssh.l"
RETURN_FFLAGS (ff_Tag3)
	YY_BREAK
case 178:
YY_RULE_SETUP
#line 289 "lexssh.l"
RETURN_FFLAGS (ff_Tag4)
	YY_BREAK
case 179:
YY_RULE_SETUP
#line 290 "lexssh.l"
RETURN_FFLAGS (ff_Index1)
	YY_BREAK
case 180:
YY_RULE_SETUP
#line 291 "lexssh.l"
RETURN_FFLAGS (ff_Index2)
	YY_BREAK
case 181:
YY_RULE_SETUP
#line 292 "lexssh.l"
RETURN_FFLAGS (ff_Index3)
	YY_BREAK
case 182:
YY_RULE_SETUP
#line 293 "lexssh.l"
RETURN_FFLAGS (ff_Index4)
	YY_BREAK
case 183:
YY_RULE_SETUP
#line 294 "lexssh.l"
RETURN_FFLAGS (ff_Encoding)
	YY_BREAK
case 184:
YY_RULE_SETUP
#line 295 "lexssh.l"
RETURN_FFLAGS (ff_Invisible)
	YY_BREAK
case 185:
YY_RULE_SETUP
#line 297 "lexssh.l"
{  yylval.string = xstrdup (yytext);
		   return tSTRING;
		}
	YY_BREAK
case 186:
YY_RULE_SETUP
#line 301 "lexssh.l"
{ return yytext[0]; }
	YY_BREAK
/* string of characters */
case 187:
YY_RULE_SETUP
#line 304 "lexssh.l"
{ /* return the string */
    unsigned char * string;

    obstack_1grow (&string_stack, '\0');
    string = (unsigned char *) obstack_finish (&string_stack);

    obstack_free (&string_stack, string);

    BEGIN INITIAL;	/* Return to the regular scanning */
    yylval.string = xstrdup (string);
    return tSTRING;
  }
	YY_BREAK
case 188:
YY_RULE_SETUP
#line 317 "lexssh.l"
{
    int value = yytext[1] - '0';
    char *cursor = yytext + 2;

    while (*cursor)
      value = 8 * value + *cursor++ - '0';
    obstack_1grow (&string_stack, value);
  }
	YY_BREAK
case 189:
YY_RULE_SETUP
#line 326 "lexssh.l"
{
    int value = 0;
    char *cursor = yytext + 2;

    while (*cursor)
      if (*cursor >= 'a' && *cursor <= 'f')
	value = 16 * value + *cursor++ - 'a' + 10;
      else if (*cursor >= 'A' && *cursor <= 'F')
	value = 16 * value + *cursor++ - 'A' + 10;
      else
	value = 16 * value + *cursor++ - '0';
    obstack_1grow (&string_stack, value);
  }
	YY_BREAK
case 190:
YY_RULE_SETUP
#line 340 "lexssh.l"
{ obstack_1grow (&string_stack, '\007'); }
	YY_BREAK
case 191:
YY_RULE_SETUP
#line 341 "lexssh.l"
{ obstack_1grow (&string_stack, '\b'); }
	YY_BREAK
case 192:
YY_RULE_SETUP
#line 342 "lexssh.l"
{ obstack_1grow (&string_stack, 127); }
	YY_BREAK
case 193:
YY_RULE_SETUP
#line 343 "lexssh.l"
{ obstack_1grow (&string_stack, 27); }
	YY_BREAK
case 194:
YY_RULE_SETUP
#line 344 "lexssh.l"
{ obstack_1grow (&string_stack, '\f'); }
	YY_BREAK
case 195:
YY_RULE_SETUP
#line 345 "lexssh.l"
{ obstack_1grow (&string_stack, '\n'); }
	YY_BREAK
case 196:
YY_RULE_SETUP
#line 346 "lexssh.l"
{ obstack_1grow (&string_stack, '\r'); }
	YY_BREAK
case 197:
YY_RULE_SETUP
#line 347 "lexssh.l"
{ obstack_1grow (&string_stack, '\t'); }
	YY_BREAK
case 198:
YY_RULE_SETUP
#line 348 "lexssh.l"
{ obstack_1grow (&string_stack, '\v'); }
	YY_BREAK
case 199:
YY_RULE_SETUP
#line 349 "lexssh.l"
{ obstack_1grow (&string_stack, yytext[1]); }
	YY_BREAK
case 200:
/* rule 200 can match eol */
YY_RULE_SETUP
#line 351 "lexssh.l"
{
    yyerror (_("end-of-line in string constant"));
  }
	YY_BREAK
case 201:
YY_RULE_SETUP
#line 355 "lexssh.l"
{
    obstack_grow (&string_stack, yytext, yyleng);
  }
	YY_BREAK

/* a regular expression */
case 202:
YY_RULE_SETUP
#line 361 "lexssh.l"
{ /* return the string */
    char * pattern;
    int pattern_len;

    /* I'm not sure I got the 0 terminate the pattern */
    obstack_1grow (&string_stack, '\0');
    pattern_len = obstack_object_size (&string_stack);
    pattern = (char *) obstack_finish (&string_stack);
    obstack_free (&string_stack, pattern);

    yylval.pattern = XMALLOC (struct pattern);
    /* len - 1, because the NUL must not be part of the pattern that
     * will be compiled.  We put tough, to be able to use the pattern
     * in regular C strings manipulations. */
    yylval.pattern->len = pattern_len - 1;
    yylval.pattern->pattern = XNMALLOC (pattern_len, char);
    memcpy (yylval.pattern->pattern, pattern, pattern_len);

    BEGIN INITIAL;	/* Return to the regular scanning */
    return tREGEX;
  }
	YY_BREAK
case 203:
YY_RULE_SETUP
#line 383 "lexssh.l"
{
    int value = yytext[1] - '0';
    char *cursor = yytext + 2;

    while (*cursor)
      value = 8 * value + *cursor++ - '0';
    obstack_1grow (&string_stack, value);
  }
	YY_BREAK
case 204:
YY_RULE_SETUP
#line 392 "lexssh.l"
{
    int value = 0;
    char *cursor = yytext + 2;

    while (*cursor)
      if (*cursor >= 'a' && *cursor <= 'f')
	value = 16 * value + *cursor++ - 'a' + 10;
      else if (*cursor >= 'A' && *cursor <= 'F')
	value = 16 * value + *cursor++ - 'A' + 10;
      else
	value = 16 * value + *cursor++ - '0';
    obstack_1grow (&string_stack, value);
  }
	YY_BREAK
case 205:
YY_RULE_SETUP
#line 406 "lexssh.l"
{ obstack_1grow (&string_stack, '\007'); }
	YY_BREAK
case 206:
YY_RULE_SETUP
#line 407 "lexssh.l"
{ obstack_1grow (&string_stack, '\b'); }
	YY_BREAK
case 207:
YY_RULE_SETUP
#line 408 "lexssh.l"
{ obstack_1grow (&string_stack, 127); }
	YY_BREAK
case 208:
YY_RULE_SETUP
#line 409 "lexssh.l"
{ obstack_1grow (&string_stack, 27); }
	YY_BREAK
case 209:
YY_RULE_SETUP
#line 410 "lexssh.l"
{ obstack_1grow (&string_stack, '\f'); }
	YY_BREAK
case 210:
YY_RULE_SETUP
#line 411 "lexssh.l"
{ obstack_1grow (&string_stack, '\n'); }
	YY_BREAK
case 211:
YY_RULE_SETUP
#line 412 "lexssh.l"
{ obstack_1grow (&string_stack, '\r'); }
	YY_BREAK
case 212:
YY_RULE_SETUP
#line 413 "lexssh.l"
{ obstack_1grow (&string_stack, '\t'); }
	YY_BREAK
case 213:
YY_RULE_SETUP
#line 414 "lexssh.l"
{ obstack_1grow (&string_stack, '\v'); }
	YY_BREAK
case 214:
YY_RULE_SETUP
#line 415 "lexssh.l"
{ obstack_1grow (&string_stack, yytext[1]); }
	YY_BREAK
case 215:
/* rule 215 can match eol */
YY_RULE_SETUP
#line 417 "lexssh.l"
{
    error_at_line (1, 0, sshfilename, sshlineno,
		   _("end of line inside a %s"), "\"..\"");
  }
	YY_BREAK
case 216:
YY_RULE_SETUP
#line 422 "lexssh.l"
{
    obstack_grow (&string_stack, yytext, yyleng);
  }
	YY_BREAK

case 217:
YY_RULE_SETUP
#line 427 "lexssh.l"
ECHO;
	YY_BREAK
#line 2824 "lexssh.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(STATE_STRING):
case YY_STATE_EOF(STATE_REGEXP):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2)  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 901 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 901 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 900);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

    static void yyunput (int c, char * yy_bp )
{
	char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		int number_to_move = (yy_n_chars) + 2;
		char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = (int) YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

    if ( c == '\n' ){
        --yylineno;
    }

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (int) ((yy_c_buf_p) - (yytext_ptr));
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	if ( c == '\n' )
		
    yylineno++;
;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2)  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf  );

	yyfree( (void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr )
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg )
{
			fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    /* We do not touch yylineno unless the option is enabled. */
    yylineno =  1;
    
    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 427 "lexssh.l"


int
yywrap (void)
{
  return 1;
}

/*
 * Initialize the obstacks
 */
void
sshlex_initialize (void)
{
  static int first_time = 1;
  if (first_time)
    {
      first_time = 0;
      obstack_init (&string_stack);
    }
}

